@@ -8,7 +8,7 @@ use warnings;
 use Class::Utils qw(set_params);
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -286,7 +286,7 @@ Constructor.
 =item * C<ae_table>
 
  AE table.
- Default value is {}
+ Default value is {}.
 
 =item * C<comment>
 
@@ -441,6 +441,16 @@ Constructor.
 
 L<Class::Utils>.
 
+=head1 SEE ALSO
+
+=over
+
+=item L<Task::Dicom>
+
+Install the Dicom modules.
+
+=back
+
 =head1 REPOSITORY
 
 L<https://github.com/tupinek/Dicom-DCMTK-DCMQRSCP-Config>
@@ -453,10 +463,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © 2014-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
